@@ -17,7 +17,8 @@ namespace TranslationToolKit
         {
             Quit,
             DuplicateCheck,
-            ApplyChanges
+            ApplyChanges,
+            CountLines
         };
 
         /// <summary>
@@ -86,6 +87,11 @@ namespace TranslationToolKit
                             ApplyChanges();
                             break;
                         }
+                        case Commands.CountLines:
+                        {
+                            CountLines();
+                            break;
+                        }
                     }
                 }
                 catch (Exception e)
@@ -105,7 +111,8 @@ namespace TranslationToolKit
             Console.WriteLine("");
             Console.WriteLine("What do you want to do ?");
             Console.WriteLine("1- Duplicates checker");
-            Console.WriteLine("2- Apply changes from master EN file to translated file");
+            Console.WriteLine("2- Synchronize changes from a reference file to a target translation file");
+            Console.WriteLine("3- Count the number of lines that you have translated versus what remains to be done");
             Console.WriteLine("0- Quit");
             bool parsed;
             Commands command;
@@ -180,15 +187,10 @@ namespace TranslationToolKit
         /// </summary>
         private void ApplyChanges()
         {
-            var checker = new ChangesApplier();
+            var checker = new FileSynchronizer();
 
-            ConsoleWrite($"{Environment.NewLine}=== Changes applier ==={Environment.NewLine}", ConsoleColor.Green);
-            ConsoleWrite($"This tool will compare a reference file (ENglish translation probably) with a target file. You MUST have run the Duplicates checker on BOTH files before running this tool, otherwise it won't perform properly{Environment.NewLine}", ConsoleColor.Yellow);
-
-            if(!AskYesNoQuestion("Have you run the duplicates checkers on both files and are you ready to proceed", ConsoleColor.Yellow))
-            {
-                return;
-            }
+            ConsoleWrite($"{Environment.NewLine}=== File Synchronizer ==={Environment.NewLine}", ConsoleColor.Green);
+            ConsoleWrite($"This tool will compare a reference file (ENglish translation probably) with a target file.{Environment.NewLine}You MUST have run the Duplicates checker on BOTH files before running this tool, otherwise it won't perform properly{Environment.NewLine}", ConsoleColor.Yellow);
 
             string referencePath;
             string targetPath;
@@ -197,7 +199,7 @@ namespace TranslationToolKit
             {
                 ConsoleWrite("Please enter the path to the reference file you want to use", ConsoleColor.Cyan);
                 referencePath = Console.ReadLine();
-                if (!ChangesApplier.IsFileValid(referencePath, out error))
+                if (!FileSynchronizer.IsFileValid(referencePath, out error))
                 {
                     DisplayErrorIfAny(error);
                 }
@@ -207,7 +209,7 @@ namespace TranslationToolKit
             {
                 ConsoleWrite("Please enter the path to the translation file that you want to check", ConsoleColor.Cyan);
                 targetPath = Console.ReadLine();
-                if (!ChangesApplier.IsFileValid(targetPath, out error))
+                if (!FileSynchronizer.IsFileValid(targetPath, out error))
                 {
                     DisplayErrorIfAny(error);
                 }
@@ -220,10 +222,7 @@ namespace TranslationToolKit
                 var report = checker.RunAnalyzer(referencePath, targetPath);
                 Console.WriteLine(report.GetDisplayString());
 
-                if (report.NewLines.Count == 0 
-                    && report.NewSections.Count == 0
-                    && report.DeletedSections.Count == 0
-                    && report.DeletedLines.Count == 0)
+                if (!report.IssuesFound)
                 {
                     return;
                 }
@@ -252,6 +251,45 @@ namespace TranslationToolKit
             return;
         }
 
+        /// <summary>
+        /// Lines counter.
+        /// </summary>
+        private void CountLines()
+        {
+            var checker = new LinesCounter();
+
+            ConsoleWrite($"{Environment.NewLine}=== Lines Counter ==={Environment.NewLine}", ConsoleColor.Green);
+            ConsoleWrite($"This tool is here to help you feel better about your translation work:{Environment.NewLine}It counts the number of lines in a reference file, then compares them with a target file, and tells you how many lines you've already translated.{Environment.NewLine}Note that this is not a serious tool as it only can only count which lines are different between the two files, and can't know which lines are left untranslated/identical on purpose.{Environment.NewLine}Still, I find it's good for motivation to see numbers go up as you keep on translating lines.{Environment.NewLine}", ConsoleColor.Magenta);
+            ConsoleWrite($"You MUST have run the Duplicates checker on BOTH files before running this tool, otherwise it won't perform properly{Environment.NewLine}", ConsoleColor.Yellow);
+
+            string referencePath;
+            string targetPath;
+            string error;
+            do
+            {
+                ConsoleWrite("Please enter the path to the reference file you want to use", ConsoleColor.Cyan);
+                referencePath = Console.ReadLine();
+                if (!FileSynchronizer.IsFileValid(referencePath, out error))
+                {
+                    DisplayErrorIfAny(error);
+                }
+            } while (error != "");
+
+            do
+            {
+                ConsoleWrite("Please enter the path to the translation file that you want to check", ConsoleColor.Cyan);
+                targetPath = Console.ReadLine();
+                if (!FileSynchronizer.IsFileValid(targetPath, out error))
+                {
+                    DisplayErrorIfAny(error);
+                }
+            } while (error != "");
+
+            Console.WriteLine();
+            var report = checker.RunAnalyzer(referencePath, targetPath);
+            ConsoleWrite(report.GetDisplayString(), ConsoleColor.Green);
+        }
+
         /// <summary>
         /// An helper method for all theses times where you need to get a Yes or No answer from the user.
         /// </summary>
